@@ -19,14 +19,19 @@ from .base_dl import _get_tensorflow_version
 from ..utils.utility import check_parameter
 
 # if tensorflow 2, import from tf directly
-if _get_tensorflow_version() == 1:
+if _get_tensorflow_version() < 200:
     raise NotImplementedError('Model not implemented for Tensorflow version 1')
 
+elif 200 <= _get_tensorflow_version() <= 209:
+    import tensorflow as tf
+    from tensorflow.keras.models import Model
+    from tensorflow.keras.layers import Input, Dense, Dropout
+    from tensorflow.keras.optimizers import Adam
 else:
     import tensorflow as tf
     from tensorflow.keras.models import Model
     from tensorflow.keras.layers import (Input, Dense, Dropout)
-    from tensorflow.keras.optimizers import Adam
+    from tensorflow.keras.optimizers.legacy import Adam
 
 
 class AnoGAN(BaseDetector):
@@ -211,7 +216,7 @@ class AnoGAN(BaseDetector):
         ax.plot(range(len(l_gen)), l_gen, )
         ax.set_title('Generator')
         ax.set_ylabel('Loss')
-        ax.set_ylabel('Iter')
+        ax.set_xlabel('Iter')
 
         ax = fig.add_subplot(1, 2, 2)
         ax.plot(range(len(l_disc)), l_disc)
