@@ -21,14 +21,18 @@ from .gaal_base import create_discriminator
 from .gaal_base import create_generator
 
 # if tensorflow 2, import from tf directly
-if _get_tensorflow_version() == 1:
+if _get_tensorflow_version() < 200:
     from keras.layers import Input
     from keras.models import Model
     from keras.optimizers import SGD
-else:
+elif 200 <= _get_tensorflow_version() <= 209:
     from tensorflow.keras.layers import Input
     from tensorflow.keras.models import Model
     from tensorflow.keras.optimizers import SGD
+else:
+    from tensorflow.keras.layers import Input
+    from tensorflow.keras.models import Model
+    from tensorflow.keras.optimizers.legacy import SGD
 
 
 class SO_GAAL(BaseDetector):
@@ -59,9 +63,6 @@ class SO_GAAL(BaseDetector):
     lr_g : float, optional (default=0.0001)
         The learn rate of the generator.
 
-    decay : float, optional (default=1e-6)
-        The decay parameter for SGD.
-
     momentum : float, optional (default=0.9)
         The momentum parameter for SGD.
 
@@ -84,13 +85,11 @@ class SO_GAAL(BaseDetector):
         ``threshold_`` on ``decision_scores_``.
     """
 
-    def __init__(self, stop_epochs=20, lr_d=0.01, lr_g=0.0001,
-                 decay=1e-6, momentum=0.9, contamination=0.1):
+    def __init__(self, stop_epochs=20, lr_d=0.01, lr_g=0.0001, momentum=0.9, contamination=0.1):
         super(SO_GAAL, self).__init__(contamination=contamination)
         self.stop_epochs = stop_epochs
         self.lr_d = lr_d
         self.lr_g = lr_g
-        self.decay = decay
         self.momentum = momentum
 
     def fit(self, X, y=None):
@@ -119,8 +118,7 @@ class SO_GAAL(BaseDetector):
 
         self.discriminator = create_discriminator(latent_size, data_size)
         self.discriminator.compile(
-            optimizer=SGD(lr=self.lr_d, decay=self.decay,
-                          momentum=self.momentum), loss='binary_crossentropy')
+            optimizer=SGD(lr=self.lr_d, momentum=self.momentum), loss='binary_crossentropy')
 
         self.generator = create_generator(latent_size)
         latent = Input(shape=(latent_size,))
@@ -129,8 +127,7 @@ class SO_GAAL(BaseDetector):
         fake = self.discriminator(fake)
         self.combine_model = Model(latent, fake)
         self.combine_model.compile(
-            optimizer=SGD(lr=self.lr_g, decay=self.decay,
-                          momentum=self.momentum), loss='binary_crossentropy')
+            optimizer=SGD(lr=self.lr_g, momentum=self.momentum), loss='binary_crossentropy')
 
         # Start iteration
         for epoch in range(epochs):
